---
name: Feature Request
about: '"It would be really cool if x did y..."'
title: ''
labels: ''
assignees: ''

---

This text document allows the plugin developers to gather the information they need to understand and prioritize your feature request. Please write your responses in the space below each section (replace [your answer here] with your answer), then click the "Submit new issue" button when you are finished. You can preview the formatting of this document using the Preview tab above.

## Requested feature
*Describe the new feature you would like to see in the napari-segmenter plugin.*
[your answer here]

## Use case
*What will this change enable you to do?*
[your answer here]

## If this change is NOT made...
Check all that apply, by entering an x inside the brackets:
- [ ] I will not use the napari-segmenter plugin.
- [ ] I will be blocked from completing my current tasks.
- [ ] I can accomplish what I need to accomplish, but it's tedious.
- [ ] Not a problem right this minute, but this is going to be a problem soon.
- [ ] Everything's fine! But it would be cool if this work happened at some point in the future.

## Alternatives
*Are there any other plugins or software that you would use in place of this feature?*
[your answer here]
